@@ -3,8 +3,6 @@
 import builtins
 from dotenv import load_dotenv, find_dotenv
 import functools
-import sentry_sdk
-from sentry_sdk import utils as sentry_utils
 import os
 
 # set __version__ module
@@ -31,14 +29,6 @@ from toolchest_client.api.exceptions import ToolchestException, DataLimitError,
 from toolchest_client.api.query import Query
 from toolchest_client.api.status import Status, get_status
 from toolchest_client.api.urls import get_api_url, set_api_url
-from .tools.api import add_database, alphafold, blastn, bowtie2, cellranger_count, clustalo, demucs, diamond_blastp, \
-    diamond_blastx, humann3, kraken2, megahit, python3, rapsearch, rapsearch2, salmon, shi7, shogun_align, \
-    shogun_filter, STAR, test, transfer, unicycler, update_database
-
-sentry_utils.MAX_STRING_LENGTH = 8192  # monkey patch for Sentry max message length
-sentry_sdk.init(
-    None,
-
-    traces_sample_rate=0.0,
-    environment=os.getenv("DEPLOY_ENVIRONMENT", 'production')
-)
+from .tools.api import add_database, alphafold, blastn, bowtie2, bracken, cellranger_count, clustalo, demucs,\
+    diamond_blastp, diamond_blastx, humann3, kraken2, lug, megahit, python3, rapsearch, rapsearch2, salmon, shi7, \
+    shogun_align, shogun_filter, STAR, test, transfer, unicycler, update_database
