@@ -2,12 +2,14 @@ from .tool import Tool
 from .alphafold import AlphaFold
 from .blastn import BLASTN
 from .bowtie2 import Bowtie2
+from .bracken import Bracken
 from .cellranger import CellRangerCount
 from .clustalo import ClustalO
 from .demucs import Demucs
 from .diamond import DiamondBlastp, DiamondBlastx
 from .humann import HUMAnN3
 from .kraken2 import Kraken2
+from .lug import Lug
 from .megahit import Megahit
 from .python3 import Python3
 from .rapsearch2 import Rapsearch2
